package planet.behaviour;

import planet.commonapi.Node;
import planet.commonapi.RouteMessage;
import planet.behaviour.exception.NoBehaviourDispatchedException;
import planet.behaviour.exception.NoSuchBehaviourException;

/**
 * The BehavioursPool's interface is aimed at providing an internal  scheduler of
 * node's behaviuours. At startup, behaviours are registered to the pool from 
 * Behaviour.properties file, following the next syntax:
 *     
 *      Class = Type, Mode, Probability 
 * 
 * Then, a message interceptor is build up and is ready to invoke  behaviours
 * when a message pattern matches to those provided by <b> Behaviour.properties </b>
 * file.  
 * @author <a href="mailto: marc.sanchez@estudiants.urv.es">Marc Sanchez</a>
 * Date: 10/10/2004   
 */
public interface BehavioursPool {
	/*
	 * Mandatory property: a public constant named "NumberOfTypes" valued with the total number  
	 * of types must be included on node's impl.
	 */
	public final static String NumberOfTypes = "NumberOfTypes";
	/*
	 * Mandatory property: a public constant named "NumberOfModes" valued with the total number  
	 * of modes must be included on node's impl.
	 */
	public final static String NumberOfModes = "NumberOfModes";	
	/**
	 * Given a RouteMessage and a Node as input, onMessage's method intends to
	 * invoke some behaviours only if RouteMessage's type and mode fields matches
	 * some behaviour's pattern.  
	 * @param msg RoteMessage taken as input.
	 * @param node Node taken as input.
	 * @return Returns either an array of RouteMessages or null when no messages
	 * need to transmit this node.
	 * @throws NoSuchBehaviourException when no behaviour matches RouteMessage's
	 * pattern. 
	 */
	public RouteMessage[] onMessage(RouteMessage msg, Node node) throws NoSuchBehaviourException,NoBehaviourDispatchedException;
}
