package planet.dht;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import planet.commonapi.exception.InitializationException;

/**
 * This class includes the initialization and the values for all
 * configuration properties of a generic DHT overlay.
  * @author <a href="mailto: marc.sanchez@estudiants.urv.es">Marc Sanchez</a>
 * Date: 12/08/2004
 */
public class DHTProperties implements planet.util.DHTProperties {

	/* *********************** GENERIC DHT PROPERTIES ***********************/
	/* Theese must to appear on the properties file */
	/**
	 * DHT property: Default key for number of replicas
	 */
	public static final String DEFAULT_REPLICATION_RATIO = "DEFAULT_REPLICATION_RATIO";
	/**
	 * DHT property: Default key for number of replicas
	 */
	public static final String DEFAULT_REPLICATION_STAB = "DEFAULT_REPLICATION_STAB";
	
	public String TYPES[] = {"DEFAULT_REPLICATION_RATION",
							 "DEFAULT_REPLICATION_STAB",
							};

	/* *************** ATTRIBUTES FOR DHT  ****************/
	/**
	 * Number of replicas
	 */
	public int replicationRatio;
	/**
	 * Number of step to run replica's maintenance algorithm
	 */
	public int replicationStabSteps;
	/**
	 * Initialize all configuration properties of a generic DHT application layer
	 * @see planet.util.OverlayProperties#init(java.lang.String)
	 * @param propertiesFile
	 * @throws InitializationException
	 */
	public void init(String propertiesFile) throws InitializationException {
		//Load properties
		FileInputStream fis = null;
		java.util.Properties prop = new java.util.Properties();
		try {
			fis = new FileInputStream(propertiesFile);
			prop.load(fis);
		} catch (FileNotFoundException e) {
			throw new InitializationException("Cannot read the file "+propertiesFile,e);
		} catch (IOException e) {
			throw new InitializationException("Cannot load the file "+propertiesFile,e);
		}
		
		// DEFAULT_REPLICATION_RATIO
		replicationRatio = Integer.parseInt(prop.getProperty(DEFAULT_REPLICATION_RATIO));
		if (replicationRatio < 0) 
				throw new InitializationException("Property ["+DEFAULT_REPLICATION_RATIO +"] is not a valid replication ratio.");
		
		// DEFAULT_REPLICATION_RATIO
		replicationStabSteps = Integer.parseInt(prop.getProperty(DEFAULT_REPLICATION_STAB));
		if (replicationStabSteps < 0) 
				throw new InitializationException("Property ["+DEFAULT_REPLICATION_STAB +"] is not a valid number of replication steps.");
		
	}
	/**
	 * Returns a String representation of the constant specific values
	 * of type and mode of the RouteMessage. Its use is only for
	 * human readable logs. 
	 * @param type Value to get its String representation.
	 * @return The String representation of the type.
	 */
	public String typeToString(int type) {
		try  {
			return TYPES[type];
		} catch(ArrayIndexOutOfBoundsException e) {
			return "none";
		}
	}
}
