package planet.generic.commonapi.GML;

import java.io.FileInputStream;
import java.io.FileNotFoundException;
import java.io.IOException;

import planet.commonapi.exception.InitializationException;
import planet.util.PropertiesInitializer;

/**
 * Default graphical properties for GML graphs.
 * @author <a href="mailto: marc.sanchez@estudiants.urv.es">Marc Sanchez </a>
 * @author <a href="mailto: jordi.pujol@estudiants.urv.es">Jordi Pujol </a>
 */
public class GMLDefaultProperties implements PropertiesInitializer {
    
    /* *********** GML GRAPH PROPERTIES **********/
    /** Width Of  The Virtual Bounding Box  */
    public static final String DEFAULT_WIDTH = "DEFAULT_WIDTH";
    /** Height Of The Virtual Bounding Box*/
    public static final String DEFAULT_HEIGHT = "DEFAULT_HEIGHT";
    /**  Shape Of The Node */  		
    public static final String DEFAULT_SHAPE = "DEFAULT_SHAPE";
    /** Fill Color For The Shape Of the Node  (in #'RRGGBB' format) */
    public static final String DEFAULT_FILL = "DEFAULT_FILL";
    /** Alternative Fill Color For the Shape Of The Node  (in #'RRGGBB' format) */
    public static final String DEFAULT_ALTERNATIVE_FILL = "DEFAULT_ALTERNATIVE_FILL";
    /** Color Of The Border Line (in #'RRGGBB' format) */
    public static final String DEFAULT_OUTLINE = "DEFAULT_OUTLINE"; 
    /** Font Size Of the Node Id Label */
    public static final String DEFAULT_FONT_SIZE = "DEFAULT_FONT_SIZE";
    /** Font Name Of the Node Id Label */
    public static final String DEFAULT_FONT_NAME = "DEFAULT_FONT_NAME";
    /** Minimal Node Distance arranged on a circle */
    public static final String DEFAULT_MINIMAL_NODE_DISTANCE = "DEFAULT_MINIMAL_NODE_DISTANCE";
    
    /* ********************** DEFAULT ATTRIBUTE VALUES ******************/
    /** Width Of  The Virtual Bounding Box. */
  	public static final float WIDTH = 20.0f;
  	
  	/** Height Of The Virtual Bounding Box */
  	public static final float HEIGHT = 20.0f;
  	
  	/** Shape Of The Node */  		
  	public static final String SHAPE = "ellipse";
  	
  	/** Fill Color For The Shape Of the Node */
  	public static final String FILL = "#CCCCFF";
  	
  	/** Alternative Fill Color For the Shape Of The Node */
  	public static final String ALTERNATIVE_FILL=  "#00FF66";

  	/** Color Of The Border Line */
  	public static final String OUTLINE ="#000000"; 
  	
  	/** Font Size Of the Node Id Label */
  	public static final int FONT_SIZE = 12;
  	
  	/** Font Name Of the Node Id Label */
  	public static final String FONT_NAME = "dialog";
  	
  	/** Minimal Node Distance arranged on a circle */
  	public static final int MINIMAL_NODE_DISTANCE = 50;
    
    
  	/* *********** ACTUAL GML GRAPH ATTRIBUTES **********/
	/** Width Of  The Virtual Bounding Box. */
  	public float w = 20.0f;
  	
  	/** Height Of The Virtual Bounding Box */
  	public float h = 20.0f;
  	
  	/** Shape Of The Node */  		
  	public String shape = "ellipse";
  	
  	/** Fill Color For The Shape Of the Node */
  	public String fill = "#CCCCFF";
  	
  	/** Alternative Fill Color For the Shape Of The Node */
  	public String alternativeFill =  "#00FF66";

  	/** Color Of The Border Line */
  	public String outline ="#000000"; 
  	
  	/** Font Size Of the Node Id Label */
  	public int fontSize = 12;
  	
  	/** Font Name Of the Node Id Label */
  	public String fontName = "dialog";
  	
  	/** Minimal Node Distance arranged on a circle */
  	public int minimalNodeDistance = 50;
  	
  	
  	/**
	 * Loads the default values specified in the <b>propertiesFile</b>
	 * for GML purposes.
	 * @throws InitializationException if an error occurs during  the initialization
	 * of the different properties.
	 * @param propertiesFile File with all GML configuration properties. 
	 * This file must follow java.util.Properties scheme. If it is null,
	 * nothing is done.
	 */
	public void init(String propertiesFile) throws InitializationException {
	    if (propertiesFile==null) //using default values.
	    {
	         w = WIDTH;
	         h = HEIGHT;
	         shape = new String(SHAPE);
	         fill = new String(FILL);
	         alternativeFill = new String (ALTERNATIVE_FILL);
	         outline = new String (OUTLINE);
	         fontSize = FONT_SIZE;
	         fontName = new String (FONT_NAME);
	         minimalNodeDistance = MINIMAL_NODE_DISTANCE;
	         return;
	    }
	    
		// Load properties
		FileInputStream fis = null;
		java.util.Properties props = new java.util.Properties();
		try {
			fis = new FileInputStream(propertiesFile);
			props.load(fis);
		} catch (FileNotFoundException e) {
			throw new InitializationException("Error On Property File '" + propertiesFile + "'",e);
		} catch (IOException e) {
			throw new InitializationException("Error On Property File '" + propertiesFile + "'",e);
		}
		
		// DEFAULT_WIDTH
		if (props.containsKey(DEFAULT_WIDTH)) {
		    try {
		        w = Float.parseFloat(props.getProperty(DEFAULT_WIDTH));
		    } catch (NumberFormatException e)
		    {}
		}
		
		// DEFAULT_HEIGHT
		if (props.containsKey(DEFAULT_HEIGHT)) {
			h = Float.parseFloat(props.getProperty(DEFAULT_HEIGHT));
		}
		
		// DEFAULT_SHAPE
		if (props.containsKey(DEFAULT_SHAPE)) {
			shape = props.getProperty(DEFAULT_SHAPE);
		}
		
		// DEFAULT_FILL
		if (props.containsKey(DEFAULT_FILL)) {
			fill = "#"+props.getProperty(DEFAULT_FILL);
		}
		
		// DEFAULT_ALTERNATIVE_FILL
		if (props.containsKey(DEFAULT_ALTERNATIVE_FILL)) {
			alternativeFill = "#"+props.getProperty(DEFAULT_ALTERNATIVE_FILL);
		}
		
		// DEFAULT_OUTLINE
		if (props.containsKey(DEFAULT_OUTLINE)) {
			shape = "#"+props.getProperty(DEFAULT_OUTLINE);
		}
		
		// DEFAULT_FONT_SIZE
		if (props.containsKey(DEFAULT_FONT_SIZE)) {
			fontSize = Integer.parseInt(props.getProperty(DEFAULT_FONT_SIZE));
		}
		
		// DEFAULT_FONT_NAME
		if (props.containsKey(DEFAULT_FONT_NAME)) {
			fontName = props.getProperty(DEFAULT_FONT_NAME);
		}
		
		// DEFAULT_MINIMAL_NODE_DISTANCE
		if (props.containsKey(DEFAULT_MINIMAL_NODE_DISTANCE)) {
			minimalNodeDistance = Integer.parseInt(props.getProperty(DEFAULT_MINIMAL_NODE_DISTANCE));
		}
	}
}
