package planet.generic.commonapi;

import planet.commonapi.exception.InitializationException;
import planet.generic.commonapi.factory.GenericFactory;
import planet.util.Properties;

/**
 * This class only attemps to help to programmers make more simple the initialization of the 
 * required context of new applications. Are two ways to initialize the context:
 * <br><br><b>One</b><br>
 * The new application must extends this GenericApp and includes in theirs constructors the
 * sentence <b>super()</b> or <b>super(factoriesProperties,simProperties,kbrProperties)</b>.
 * For example:
 * <b><pre>
 * public NewTest() throws InitializationException {
 *     super(factoriesProperties,simProperties,kbrProperties);
 * </pre></b>
 * where parameters of super() constructor are the path to specified files.
 * <br><br><b>Two</b><br>
 * Includes theese lines before anything that make reference to the network and the simulator and ...
 * <b><pre>
 * Properties.init(factoriesProperties,simProperties,kbrProperties);
 * GenericFactory.init();
 * </pre></b>
 * where parameters of init() method are the path to specified files.
 * 
 * @author Jordi Pujol
 */
public class GenericAppWithGML {
	

	/**
	 * Make required initialization on the context of the application. In concrete:
	 * <b><pre>
	 * Properties.init(factoriesProperties,simProperties,kbrProperties);
     * GenericFactory.init();
	 * </pre></b>
	 * Because of theese lines, the new application must be executed under the implicitly specified
	 * directory by the parameters files.
	 * @param factoriesProperties Path to properties file of factories attributes.
	 * @param simProperties Path to properties file of simulator attributes.
	 * @param kbrProperties Path to properties file of chord attributes.
	 * @param gmlGraphicalProperties Path to properties file of graphical attributes.
	 * @param gmlClassesProperties Path to properties file of classes definition.
	 * @throws InitializationException if any error has occurred during initialization of the context.
	 */
	public GenericAppWithGML(String factoriesProperties,String simProperties, String kbrProperties,
	        String gmlGraphicalProperties, String gmlClassesProperties) throws InitializationException {
  		Properties.initWithGML(factoriesProperties,simProperties,kbrProperties,
  		        gmlGraphicalProperties,gmlClassesProperties);
  		GenericFactory.init();
	}
	/**
	 * Make required initialization on the context of the application. In concrete:
	 * <b><pre>
	 * Properties.init(factoriesProperties,simProperties,chordProperties);
     * GenericFactory.init();
	 * </pre></b>
	 * Because of theese lines, the new application must be executed under the implicitly specified
	 * directory by the parameters files.
	 * @param factoriesProperties Path to properties file of factories attributes.
	 * @param simProperties Path to properties file of simulator attributes.
	 * @param kbrProperties Path to properties file of kbr attributes.
	 * @param dhtProperties Path to properties file of dht attributes.
	 * @param gmlGraphicalProperties Path to properties file of graphical attributes.
	 * @param gmlClassesProperties Path to properties file of classes definition.
	 * @throws InitializationException if any error has occurred during initialization of the context.
	 */
	public GenericAppWithGML(String factoriesProperties,String simProperties, String kbrProperties, 
	        String dhtProperties, String gmlGraphicalProperties, String gmlClassesProperties) throws InitializationException {
  		Properties.initWithGML(factoriesProperties,simProperties,kbrProperties,dhtProperties,
  		      gmlGraphicalProperties,gmlClassesProperties);
  		GenericFactory.init();
	}
	/**
	 * Make required initialization on the context of the application. In concrete:
	 * <b><pre>
	 * Properties.init(factoriesProperties,simProperties,chordProperties);
     * GenericFactory.init();
	 * </pre></b>
	 * Because of theese lines, the new application must be executed under the implicitly specified
	 * directory by the parameters files.
	 * @param factoriesProperties Path to properties file of factories attributes.
	 * @param simProperties Path to properties file of simulator attributes.
	 * @param kbrProperties Path to properties file of kbr attributes.
	 * @param dhtProperties Path to properties file of dht attributes.
	 * @param behProperties Paht to properties file of behaviours attributes
 	 * @param gmlGraphicalProperties Path to properties file of graphical attributes.
	 * @param gmlClassesProperties Path to properties file of classes definition.
	 * @throws InitializationException if any error has occurred during initialization of the context.
	 */
	public GenericAppWithGML(String factoriesProperties,String simProperties, String kbrProperties, 
	        String dhtProperties, String behProperties, 
	        String gmlGraphicalProperties, String gmlClassesProperties) throws InitializationException {
  		Properties.initWithGML(factoriesProperties,simProperties,kbrProperties,
  		        dhtProperties, behProperties,
  		        gmlGraphicalProperties,gmlClassesProperties);
  		GenericFactory.init();
	}
}
