
package planet.simulate;

import java.util.Vector;
import java.io.*;
import java.util.StringTokenizer;
import java.util.Random;

import planet.chord.*;
import planet.commonapi.Id;
import planet.util.Properties;

/**
 * @author Pedro Garca
 * @author Carles Pairot
 * @author Ruben Mondejar
 * 
 */

public class EventParser {
  public static Vector parseEvents(String fileName) throws FileNotFoundException, IOException {
    Vector events = new Vector();

    FileReader fis = new FileReader(fileName);
    BufferedReader in = new BufferedReader(fis);
    String line;

    while ((line = in.readLine())!=null){
      events.addAll(parseLine(line));
    }

    return events;
  }

  public static Vector parseLine(String line) {
    StringTokenizer st = new StringTokenizer(line);
    String token;

    Vector evts = new Vector();

    token = st.nextToken();
    token = st.nextToken();
    int time = Integer.parseInt(token);
    token = st.nextToken();
    int type = getType(token);

    switch (type) {
      case Globals.JOIN:		evts.addAll (parseJoin (st, type, time));
        break;
      case Globals.LEAVE:		evts.addAll (parseLeaveFail (st, type, time));
        break;
      case Globals.LOOKUP:	        evts.addAll (parseLookup (st, type, time));
        break;
      case Globals.FAIL: 		evts.addAll (parseLeaveFail (st, type, time));
        break;
	  //case Globals.BROADCAST: 	evts.addAll (parseBroadcast (st, type, time));
	  //break;  
    }
    return evts;
  }

  public static Vector parseJoin (StringTokenizer st,int type,int time) {
    Vector evts = new Vector();
    Id id,target;

    String tid = st.nextToken();
    tid = tid.toUpperCase();
    String ttarget = st.nextToken();
    ttarget = ttarget.toUpperCase();
    String token = st.nextToken();
    int times = Integer.parseInt(token);
    int cnt = 0;
    Random r = new Random();
    for (cnt = 0; cnt < times; cnt++){
      if (tid.equals("ID")) {        
        //int[] array = {r.nextInt(), 0, 0, 0, 0};
        //id = new ChordId(array);
        id = new ChordId(new java.math.BigInteger(Properties.bitsKey,new java.util.Random()).toString());
      }
      else {
		id = new ChordId (tid);
      }

      if (ttarget.equals("ID"))
        target = null;
      else {
		target  = new ChordId (ttarget);
      }
      Event e = new Event (id,target,type,times,time);
      evts.add(e);
    }

    return evts;
  }

  public static Vector parseLookup(StringTokenizer st,int type,int time){
    Vector evts = new Vector();
    Id id,target;

    String tid = st.nextToken();
    tid = tid.toUpperCase();
    String ttarget = st.nextToken();
    ttarget = ttarget.toUpperCase();
    String token = st.nextToken();
    int times = Integer.parseInt(token);
    int cnt = 0;
    Random r = new Random();
    for (cnt=0;cnt<times;cnt++){
      if (tid.equals("ID"))
        id = null;
      else {
		id = new ChordId (tid);
      }

      if (ttarget.equals("ID")) {
		target  = new ChordId (ttarget);
      }
      else {
		target  = new ChordId(ttarget);
      }
      Event e = new Event (id,target,type,times,time);
      evts.add(e);
    }

    return evts;
  }

  public static Vector parseLeaveFail(StringTokenizer st,int type,int time) {
    Vector evts = new Vector();
    Id id,target;

    String tid = st.nextToken();
    tid = tid.toUpperCase();
    String token = st.nextToken();
    int times = Integer.parseInt(token);
    int cnt = 0;
    for (cnt=0;cnt<times;cnt++){
      if (tid.equals("ID"))
        id = null;
      else {        
		id = new ChordId (tid);        
      }

      Event e = new Event(id,null,type,times,time);
      evts.add(e);
    }

    return evts;
  }

  public static int getType(String type) {
    type = type.toUpperCase();
    if (type.equals("JOIN")){
      return Globals.JOIN;
    } else if (type.equals("LEAVE")){
      return Globals.LEAVE;
    } else if (type.equals("LOOKUP")){
      return Globals.LOOKUP;
    } else if (type.equals("FAIL")){
      return Globals.FAIL;
    }
    return -1;
  }
}
