package planet.symphony.behaviours;

import planet.commonapi.Node;
import planet.commonapi.RouteMessage;
import planet.simulate.Logger;
import planet.simulate.MessagePool;
import planet.symphony.SymphonyNode;

/**
 * IdleFilter class does not filter any RouteMessage.
 * @author Marc Sanchez		<marc.sanchez@estudiants.urv.es>
 */
public class IdleFilter  implements planet.behaviour.Filter {
	/**
	 * Given a RouteMessage and a Node as input, filter's method filters the 
	 * input RouteMessage if does not satisfy filter's precondition. 
	 * @param msg RouteMessage taken as input.
	 * @param node Node taken as input.
	 * @return Returns either an array of RouteMessages or null when no messages
	 * need to transmit this node. 
	 */
	public boolean filter(RouteMessage msg, Node node) {
		SymphonyNode symphony = (SymphonyNode) node;
		
		if (!symphony.alive) {
			Logger.log("Node " + symphony.getId() + " is not in, but it receives messages!!", Logger.ERROR_LOG);
			MessagePool.freeMessage(msg);
			return true;
		}
		
		if (msg.getDestination() == null) {
			Logger.log("destination null", Logger.ERROR_LOG);
			MessagePool.freeMessage(msg);
			return true;
		}
		return false;
	}
	/**
	 * @return Returns the name of the filter. 
	 */
	public String getName() {
		return "IdleFilter";
	}
	/**
	 * @return Returns a string representation of the filter. In general, the toString
	 * method returns a string that "textually represents" this behaviour. The result should 
	 * be a concise but informative representation that is easy for a person to read. 
	 */ 
	public String toString() {
		return getName();
	}
}
