package planet.util;

import planet.commonapi.exception.InitializationException;

/**
 * This interface allows to implement all the own properties of configuration
 * of a generic DHT application layer. It establishes a single relationship,
 * through the method init(), so that their values are initialized. For this
 * reason, cast will have to be made in each place where it is necessary, 
 * to the concrete implementation.
 * @author <a href="mailto: marc.sanchez@estudiants.urv.es">Marc Sanchez</a>
 * Date: 12/08/2004
 */
public interface DHTProperties extends java.io.Serializable {
	
	/**
	 * Initialize correctly the generic DHT configuration properties.
	 * @throws InitializationException if an error occurs during  the initialization
	 * of the different properties.
	 * @param propertiesFile File with all configuration properties of the concrete 
	 * DHT. This file must follow java.util.Properties scheme.
	 */
	public void init(String propertiesFile) throws InitializationException;
	
	/**
	 * Returns a String representation of the constant specific values
	 * of type and mode of the RouteMessage. Its use is only for human
	 * readable logs.
	 * @param type Value to get its String representation.
	 * @return The String representation of the type.
	 */
	public String typeToString(int type);
}
